@@ -6,15 +6,17 @@
 
 
 setMethod('predict', signature(object='GeographicDistance'), 
-	function(object, x, ext=NULL, filename='', mask=FALSE, progress='text', fun=NULL, ...) {
-	
+	function(object, x, ext=NULL, filename='', mask=FALSE, scale=1, fun=NULL, progress='text', ...) {
+			
 		if (is.null(fun)) {
 			inverse <- function(x) {
+				x <- x / scale
 				x[x < 1] <- 1
 				1/x
 			}
 		} else {
 			inverse <- function(x) {
+				x <- x / scale
 				x[x < 1] <- 1
 				fun(1/x)
 			}
